@@ -32,7 +32,7 @@ except ImportError:
 
 import gitshelve
 
-VERSION = "0.1.1"
+VERSION = "0.1.2"
 readline.parse_and_bind('tab: complete')
 
 git_repo = None
@@ -149,7 +149,7 @@ class DbProperty(object):
         if colorama:
             color = self._color.get(attr, None)
             if color:
-                value = color + value + colorama.Fore.RESET
+                value = color + value + colorama.Style.RESET_ALL
 
         return value
 
@@ -602,8 +602,9 @@ class CreatedOnProperty(DbProperty):
 
         else:
             default = _now()
+            self.value = default
 
-        return super(CreatedOnProperty, self).interactive_edit(default)
+        return super(CreatedOnProperty, self).interactive_edit(default=default)
 
 
 class UpdatedOnProperty(DbProperty):
@@ -628,6 +629,8 @@ class UpdatedOnProperty(DbProperty):
         Call interactive_edit from DbProperty and always provide
         current date and time as default value.
         """
+        self.value = _now()
+
         return super(UpdatedOnProperty, self).\
                interactive_edit(default=_now())
 
